==> jc-1.4.0.tar.gz: javax/swing/UIManager__24LookAndFeelInfo.c <==
// public class javax.swing.UIManager$LookAndFeelInfo

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class f595ac3f1298ecd7 javax_swing_UIManager
// @dep_class 14423075d0b21178 javax_swing_UIManager__24LookAndFeelInfo

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_UIManager
// @dep_header javax_swing_UIManager__24LookAndFeelInfo

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/UIManager.h"
#include "javax/swing/UIManager__24LookAndFeelInfo.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.String name
static _jc_field _jc_javax_swing_UIManager__24LookAndFeelInfo$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_UIManager__24LookAndFeelInfo$object, refs[-1].javax_swing_UIManager__24LookAndFeelInfo.name),
};

// java.lang.String clazz
static _jc_field _jc_javax_swing_UIManager__24LookAndFeelInfo$field_info$clazz = {
	.name=		"clazz",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_UIManager__24LookAndFeelInfo$object, refs[-1].javax_swing_UIManager__24LookAndFeelInfo.clazz),
};

// Fields
static _jc_field *const _jc_javax_swing_UIManager__24LookAndFeelInfo$fields[] = {
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$field_info$clazz,
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$field_info$name
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, java.lang.String)
//

static _jc_linenum _jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$_init$a34354cd9552963f[];

static const unsigned char _jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$_init$a34354cd9552963f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_UIManager__24LookAndFeelInfo$param_types$_init$a34354cd9552963f[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$_init$a34354cd9552963f = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.param_types=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$param_types$_init$a34354cd9552963f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$_init$a34354cd9552963f,
	.signature_hash=	_JC_JLONG(0xa34354cd9552963f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$_init$a34354cd9552963f,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$_init$a34354cd9552963f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_UIManager__24LookAndFeelInfo, _init$a34354cd9552963f);

void
_jc_javax_swing_UIManager__24LookAndFeelInfo$method$_init$a34354cd9552963f(_jc_env *const env, _jc_javax_swing_UIManager__24LookAndFeelInfo$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(62);				// 0
	_JC_REF_FIELD(env, r0, javax_swing_UIManager__24LookAndFeelInfo, name) = r1;
	_JC_LINE_NUMBER(63);				// 1
	_JC_REF_FIELD(env, r0, javax_swing_UIManager__24LookAndFeelInfo, clazz) = r2;
	_JC_LINE_NUMBER(64);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getClassName()
//

static _jc_linenum _jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$getClassName$333433582f896913[];

static const unsigned char _jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$getClassName$333433582f896913[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getClassName$333433582f896913 = {
	.name=			"getClassName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$getClassName$333433582f896913,
	.signature_hash=	_JC_JLONG(0x333433582f896913),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getClassName$333433582f896913,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtable, javax_swing_UIManager__24LookAndFeelInfo.getClassName$333433582f896913) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$getClassName$333433582f896913
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_UIManager__24LookAndFeelInfo, getClassName$333433582f896913);

_jc_java_lang_String$object *
_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getClassName$333433582f896913(_jc_env *const env, _jc_javax_swing_UIManager__24LookAndFeelInfo$object *this)
{
	struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(73);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_swing_UIManager__24LookAndFeelInfo, clazz);
	return r1;
}

//
// public java.lang.String getName()
//

static _jc_linenum _jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$getName$bec186f2ce7e1882[];

static const unsigned char _jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$getName$bec186f2ce7e1882[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getName$bec186f2ce7e1882 = {
	.name=			"getName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$getName$bec186f2ce7e1882,
	.signature_hash=	_JC_JLONG(0xbec186f2ce7e1882),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getName$bec186f2ce7e1882,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtable, javax_swing_UIManager__24LookAndFeelInfo.getName$bec186f2ce7e1882) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$getName$bec186f2ce7e1882
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_UIManager__24LookAndFeelInfo, getName$bec186f2ce7e1882);

_jc_java_lang_String$object *
_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getName$bec186f2ce7e1882(_jc_env *const env, _jc_javax_swing_UIManager__24LookAndFeelInfo$object *this)
{
	struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(68);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_swing_UIManager__24LookAndFeelInfo, name);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_UIManager__24LookAndFeelInfo$methods[] = {
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$_init$a34354cd9552963f,
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getClassName$333433582f896913,
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getName$bec186f2ce7e1882
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_bucket_120[] = {
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[113]=	_jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_bucket_113,
	[120]=	_jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_bucket_120
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_UIManager__24LookAndFeelInfo$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/swing/UIManager",	_JC_JLONG(0xf595ac3f1298ecd7) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_UIManager__24LookAndFeelInfo$vtype _jc_javax_swing_UIManager__24LookAndFeelInfo$type = {
    .type= {
	.name=			"javax/swing/UIManager$LookAndFeelInfo",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x14423075d0b21178),
		.source_file=		"UIManager.java",
		.instance_size=		sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$refs) + sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$fields) / sizeof(*_jc_javax_swing_UIManager__24LookAndFeelInfo$fields),
		.fields=		_jc_javax_swing_UIManager__24LookAndFeelInfo$fields,
		.num_methods=		sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$methods) / sizeof(*_jc_javax_swing_UIManager__24LookAndFeelInfo$methods),
		.methods=		_jc_javax_swing_UIManager__24LookAndFeelInfo$methods,
		.instanceof_hash_table=	_jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_table,
		.outer_class=		&_jc_javax_swing_UIManager$type,
		.num_class_depends=		sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$class_depends) / sizeof(*_jc_javax_swing_UIManager__24LookAndFeelInfo$class_depends),
		.class_depends=		_jc_javax_swing_UIManager__24LookAndFeelInfo$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_UIManager__24LookAndFeelInfo= {
	    .getClassName$333433582f896913=
		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getClassName$333433582f896913,
	    .getName$bec186f2ce7e1882=
		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getName$bec186f2ce7e1882,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/UIManager__24LookAndFeelInfo.c <==
// public class javax.swing.UIManager$LookAndFeelInfo

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3f984981a4083b93 javax_swing_UIManager
// @dep_class 14423075d0b21178 javax_swing_UIManager__24LookAndFeelInfo

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_UIManager
// @dep_header javax_swing_UIManager__24LookAndFeelInfo

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/UIManager.h"
#include "javax/swing/UIManager__24LookAndFeelInfo.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.String name
static _jc_field _jc_javax_swing_UIManager__24LookAndFeelInfo$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_UIManager__24LookAndFeelInfo$object, refs[-1].javax_swing_UIManager__24LookAndFeelInfo.name),
};

// java.lang.String clazz
static _jc_field _jc_javax_swing_UIManager__24LookAndFeelInfo$field_info$clazz = {
	.name=		"clazz",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_UIManager__24LookAndFeelInfo$object, refs[-1].javax_swing_UIManager__24LookAndFeelInfo.clazz),
};

// Fields
static _jc_field *const _jc_javax_swing_UIManager__24LookAndFeelInfo$fields[] = {
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$field_info$clazz,
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$field_info$name
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, java.lang.String)
//

static _jc_linenum _jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$_init$a34354cd9552963f[];

static const unsigned char _jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$_init$a34354cd9552963f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_UIManager__24LookAndFeelInfo$param_types$_init$a34354cd9552963f[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$_init$a34354cd9552963f = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.param_types=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$param_types$_init$a34354cd9552963f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$_init$a34354cd9552963f,
	.signature_hash=	_JC_JLONG(0xa34354cd9552963f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$_init$a34354cd9552963f,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$_init$a34354cd9552963f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_UIManager__24LookAndFeelInfo, _init$a34354cd9552963f);

void _JC_JCNI_ATTR
_jc_javax_swing_UIManager__24LookAndFeelInfo$method$_init$a34354cd9552963f(_jc_env *const env, _jc_javax_swing_UIManager__24LookAndFeelInfo$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(62);				// 0
	_JC_REF_FIELD(env, r0, javax_swing_UIManager__24LookAndFeelInfo, name) = r1;
	_JC_LINE_NUMBER(63);				// 1
	_JC_REF_FIELD(env, r0, javax_swing_UIManager__24LookAndFeelInfo, clazz) = r2;
	_JC_LINE_NUMBER(64);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getClassName()
//

static _jc_linenum _jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$getClassName$333433582f896913[];

static const unsigned char _jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$getClassName$333433582f896913[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getClassName$333433582f896913 = {
	.name=			"getClassName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$getClassName$333433582f896913,
	.signature_hash=	_JC_JLONG(0x333433582f896913),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getClassName$333433582f896913,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtable, javax_swing_UIManager__24LookAndFeelInfo.getClassName$333433582f896913) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$getClassName$333433582f896913
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_UIManager__24LookAndFeelInfo, getClassName$333433582f896913);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getClassName$333433582f896913(_jc_env *const env, _jc_javax_swing_UIManager__24LookAndFeelInfo$object *this)
{
	struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(73);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_swing_UIManager__24LookAndFeelInfo, clazz);
	return r1;
}

//
// public java.lang.String getName()
//

static _jc_linenum _jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$getName$bec186f2ce7e1882[];

static const unsigned char _jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$getName$bec186f2ce7e1882[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getName$bec186f2ce7e1882 = {
	.name=			"getName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$param_ptypes$getName$bec186f2ce7e1882,
	.signature_hash=	_JC_JLONG(0xbec186f2ce7e1882),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getName$bec186f2ce7e1882,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_UIManager__24LookAndFeelInfo$vtable, javax_swing_UIManager__24LookAndFeelInfo.getName$bec186f2ce7e1882) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_UIManager__24LookAndFeelInfo$linenum_table$getName$bec186f2ce7e1882
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_UIManager__24LookAndFeelInfo, getName$bec186f2ce7e1882);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getName$bec186f2ce7e1882(_jc_env *const env, _jc_javax_swing_UIManager__24LookAndFeelInfo$object *this)
{
	struct _jc_javax_swing_UIManager__24LookAndFeelInfo$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(68);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_swing_UIManager__24LookAndFeelInfo, name);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_UIManager__24LookAndFeelInfo$methods[] = {
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$_init$a34354cd9552963f,
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getClassName$333433582f896913,
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$method_info$getName$bec186f2ce7e1882
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_bucket_120[] = {
	&_jc_javax_swing_UIManager__24LookAndFeelInfo$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_bucket_101,
	[120]=	_jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_bucket_120
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_UIManager__24LookAndFeelInfo$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/swing/UIManager",	_JC_JLONG(0x3f984981a4083b93) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_UIManager__24LookAndFeelInfo$vtype _jc_javax_swing_UIManager__24LookAndFeelInfo$type = {
    .type= {
	.name=			"javax/swing/UIManager$LookAndFeelInfo",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x14423075d0b21178),
		.source_file=		"UIManager.java",
		.instance_size=		sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$refs) + sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$fields) / sizeof(*_jc_javax_swing_UIManager__24LookAndFeelInfo$fields),
		.fields=		_jc_javax_swing_UIManager__24LookAndFeelInfo$fields,
		.num_methods=		sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$methods) / sizeof(*_jc_javax_swing_UIManager__24LookAndFeelInfo$methods),
		.methods=		_jc_javax_swing_UIManager__24LookAndFeelInfo$methods,
		.instanceof_hash_table=	_jc_javax_swing_UIManager__24LookAndFeelInfo$instanceof_hash_table,
		.outer_class=		&_jc_javax_swing_UIManager$type,
		.num_class_depends=		sizeof(_jc_javax_swing_UIManager__24LookAndFeelInfo$class_depends) / sizeof(*_jc_javax_swing_UIManager__24LookAndFeelInfo$class_depends),
		.class_depends=		_jc_javax_swing_UIManager__24LookAndFeelInfo$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_UIManager__24LookAndFeelInfo= {
	    .getClassName$333433582f896913=
		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getClassName$333433582f896913,
	    .getName$bec186f2ce7e1882=
		&_jc_javax_swing_UIManager__24LookAndFeelInfo$method$getName$bec186f2ce7e1882,
	},
    }
};
